# This file contains a RPM spec file for building RPM files for the
# Napatech Software Suite Driver package using rpmbuild version 4.X.
#
# This file also produces package containing the binary kernel module
# nt-driver-3gd-modules. The module contained in this package must match the
# running kernel. This package can be made optional as the kernel driver
# sources are included in nt-driver-3gd package and the module is built upon
# start if it is not already available.

# Example:
#   rpmbuild -bb ./nt-driver-3gd.spec

# Version defines
%define version_number_full 3.17.2.23-0e288
%define version_number_long 3.17.2.23
%define version_number_extension 0e288

Summary: Napatech Software Suite
Name: nt-driver-3gd
Version: %{version_number_long}
Release: %{version_number_extension}
URL: http://www.napatech.com
Distribution: Linux
Vendor: Napatech A/S
Packager: Napatech A/S
License: Proprietary
Group: Applications/System
Requires: glibc >= 2.5 systemd-units ncurses
# If the automatic kernel module build is needed the dependencies to
# make, gcc and kernel-devel can be added
# Requires: make gcc kernel-devel
Requires: nt-driver-3gd-modules
BuildRequires: kernel-devel
Source0: nt_driver_3gd-%{version_number_full}-linux.tar.gz

%description
Napatech Software Suite provides a well-defined application programming
interface which allows programmers to quickly integrate Napatech accelerators
for network monitoring and security applications into their system. In
addition, Napatech Software Suite provides advanced features for data sharing
and merging supporting multiaccelerator and multi-application integration. An
intuitive, easy-to-learn, yet powerful programming language is also provided
to allow dynamic, on-the-fly configuration of filtering and intelligent
multi-CPU distribution on Napatech accelerators.

# Driver module package
%package -n nt-driver-3gd-modules
Summary: Napatech Software Suite kernel modules
Group: Applications/System
AutoReqProv: no

%description -n nt-driver-3gd-modules
Napatech Software Suite kernel modules.

# Driver documentation package
%package -n nt-driver-3gd-docs
Summary: Napatech Software Suite documention
Group: Applications/System
BuildArch: noarch
AutoReqProv: no

%description -n nt-driver-3gd-docs
Napatech Software Suite documentation.

# Driver development package
%package -n nt-driver-3gd-devel
Summary: Napatech Software Suite development files
Group: Applications/System
BuildArch: noarch
AutoReqProv: no
Requires: nt-driver-3gd

%description -n nt-driver-3gd-devel
Napatech Software Suite development header files and examples.

# Driver examples package
%package -n nt-driver-3gd-examples
Summary: Napatech Software Suite examples
Group: Applications/System
BuildArch: noarch
AutoReqProv: no
Requires: nt-driver-3gd-devel

%description -n nt-driver-3gd-examples
Napatech Software Suite development examples.

%prep
%setup -c nt_driver_3gd-%{version_number_full}-linux
./nt_driver_3gd-linux-%{version_number_full}.run --noexec --keep

%install
# Unpack the driver and patch install script to disable low level driver build
pushd nt_driver_3gd-linux-%{version_number_full}
./install.sh --yestoall \
             --norootcheck \
             --noldconfig \
             --ignorediskcheck --installpath %{buildroot}/opt/napatech3
popd

# Fixup example Makefile install path
sed -i "s|^INSTALL_PATH?=.*|INSTALL_PATH?=/opt/napatech3|" %{buildroot}/opt/napatech3/examples/Makefile.inc

# Fixup file permissions on shared libraries to enable rpmbuild to
# automatically generate provides information
chmod a+x %{buildroot}/opt/napatech3/lib/*.so

# Install SystemD unit file
mkdir -p %{buildroot}%{_unitdir}
%__install -D -m644 nt_driver_3gd-linux-%{version_number_full}/examples/integration/systemd/ntservice.service \
           %{buildroot}%{_unitdir}/ntservice.service

# Setup libraries for ldconfig
mkdir -p %{buildroot}/etc/ld.so.conf.d
echo "/opt/napatech3/lib" > %{buildroot}/etc/ld.so.conf.d/napatech3.conf

# The uninstall file has refences to buildroot which makes the RPM
# packaging fail. Remove it since it's not needed anyway.
rm %{buildroot}/opt/napatech3/.driver.uninstall

%files
%attr(-,root,root) /opt/napatech3/bin
%attr(-,root,root) /opt/napatech3/driver/src
%attr(-,root,root) /opt/napatech3/config
%attr(-,root,root) /opt/napatech3/lib
%attr(0644,root,root) /etc/ld.so.conf.d/napatech3.conf
%attr(0644,root,root) %{_unitdir}/ntservice.service

%files -n nt-driver-3gd-modules
%attr(-,root,root) /opt/napatech3/driver/nt3gd.ko
%attr(-,root,root) /opt/napatech3/driver/nt3gd_netdev.ko

%files -n nt-driver-3gd-docs
%attr(-,root,root) /opt/napatech3/doc

%files -n nt-driver-3gd-devel
%attr(-,root,root) /opt/napatech3/include

%files -n nt-driver-3gd-examples
%attr(-,root,root) /opt/napatech3/examples

%pre
# $1==1: initial installation
# $1==2: upgrade/update

%post
# $1==1: initial installation
# $1==2: upgrade/update
/sbin/ldconfig
%systemd_post ntservice.service

%preun
# $1==0: uninstall
# $1==1: upgrade
%systemd_preun ntservice.service
# Always remove drivers. Upon upgrade they will be build again
rm -f /opt/napatech3/driver/nt3gd.ko >/dev/null 2>&1
rm -f /opt/napatech3/driver/nt3gd_netdev.ko >/dev/null 2>&1
if [ $1 -eq 0 ]; then
    # Unload driver on removal
    /opt/napatech3/bin/ntunload.sh > /dev/null 2>&1 || true
fi

%postun
# $1==0: uninstall
# $1==1: upgrade
systemctl daemon-reload > /dev/null 2>&1 || true
if [ $1 -ge 1 ] ; then
    if [ "$(systemctl is-active ntservice.service)" = "active" ]; then
        # If already running then restart ntservice
        systemctl stop ntservice.service > /dev/null 2>&1 || true
        /opt/napatech3/bin/ntload.sh --rebuild > /dev/null 2>&1 || true
        systemctl start ntservice.service > /dev/null 2>&1 || true
    else
        # Unload driver so it can be rebuild on ntservice start
        /opt/napatech3/bin/ntunload.sh > /dev/null 2>&1 || true
    fi
fi
